package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.WorkReview;

/**
 * 作品评审意见Service接口
 * 
 * @author haotian
 * @date 2024-12-11
 */
public interface IWorkReviewService 
{
    /**
     * 查询作品评审意见
     * 
     * @param reviewId 作品评审意见主键
     * @return 作品评审意见
     */
    public WorkReview selectWorkReviewByReviewId(Long reviewId);

    /**
     * 查询作品评审意见列表
     * 
     * @param workReview 作品评审意见
     * @return 作品评审意见集合
     */
    public List<WorkReview> selectWorkReviewList(WorkReview workReview);

    /**
     * 新增作品评审意见
     * 
     * @param workReview 作品评审意见
     * @return 结果
     */
    public int insertWorkReview(WorkReview workReview);

    /**
     * 修改作品评审意见
     * 
     * @param workReview 作品评审意见
     * @return 结果
     */
    public int updateWorkReview(WorkReview workReview);

    /**
     * 批量删除作品评审意见
     * 
     * @param reviewIds 需要删除的作品评审意见主键集合
     * @return 结果
     */
    public int deleteWorkReviewByReviewIds(Long[] reviewIds);

    /**
     * 删除作品评审意见信息
     * 
     * @param reviewId 作品评审意见主键
     * @return 结果
     */
    public int deleteWorkReviewByReviewId(Long reviewId);

    public int setWorkReviewDeleteFlag(WorkReview workReview);
}
